# Reference

## RougeK

Main class that performs evaluation with ROUGE-K.

::: rougek.evaluation.main.RougeK
    handler: python
    options:
      members:
        - __call__
      show_root_heading: false
      show_source: false
